#!/bin/bash
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi


# needs libglib-2.0.la
##########################

export CFLAGS="-Os -pipe -march=armv6zk -mtune=arm1176jzf-s -mfpu=vfp"
export CXXFLAGS="-Os -pipe -fno-exceptions -fno-rtti -march=armv6zk \
-mtune=arm1176jzf-s -mfpu=vfp"

P=gtk2
V=2.24.32
SRC=gtk+-2.24.32
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc wget squashfs-tools zsync gettext glib2-dev atk-dev atk-gir gdk-pixbuf-dev \
gdk-pixbuf-gir cups-dev gobject-introspection-dev pango-dev pango-gir \
libXinerama-dev libXrandr-dev libXcursor-dev libXcomposite-dev "
for Z in $LIST 
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
http://ftp.gnome.org/pub/gnome/sources/gtk+/2.24/gtk+-$V.tar.xz " $USER
mkdir $P
xz -d gt*xz && tar xvf gt*tar
cd $SRC
./configure --prefix=/usr/local --enable-cups --disable-debug --enable-introspection=yes
make -j5 # about 11 min 40s
make install-strip DESTDIR=/tmp/$P  # about 1M40s
cd /tmp

# locale
#########
mkdir -p $P-locale/usr/local/share
mv $P/usr/local/share/locale $P-locale/usr/local/share

# dev
#####
mkdir -p $P-dev/usr/local/lib/
mv $P/usr/local/include $P-dev/usr/local/
mv $P/usr/local/lib/pkgconfig $P-dev/usr/local/lib/
mv $P/usr/local/lib/*a $P-dev/usr/local/lib/
chmod 644 $P-dev/usr/local/lib/*a 

mkdir -p $P-dev/usr/local/lib/gtk-2.0/modules
mv $P/usr/local/lib/gtk-2.0/include $P-dev/usr/local/lib/gtk-2.0/
mv $P/usr/local/lib/gtk-2.0/modules/*a $P-dev/usr/local/lib/gtk-2.0/modules/
chmod 644 $P-dev/usr/local/lib/gtk-2.0/modules/*a
mkdir -p $P-dev/usr/local/lib/gtk-2.0/2.10.0
cd $P-dev/usr/local/lib/gtk-2.0/2.10.0
mkdir engines immodules printbackends
cd /tmp
mv $P/usr/local/lib/gtk-2.0/2.10.0/engines/*a $P-dev/usr/local/lib/gtk-2.0/2.10.0/engines/
mv $P/usr/local/lib/gtk-2.0/2.10.0/immodules/*a $P-dev/usr/local/lib/gtk-2.0/2.10.0/immodules/
mv $P/usr/local/lib/gtk-2.0/2.10.0/printbackends/*a $P-dev/usr/local/lib/gtk-2.0/2.10.0/printbackends/
chmod 644 $P-dev/usr/local/lib/gtk-2.0/2.10.0/engines/*
chmod 644 $P-dev/usr/local/lib/gtk-2.0/2.10.0/immodules/*a
chmod 644 $P-dev/usr/local/lib/gtk-2.0/2.10.0/printbackends/*a

mkdir -p $P-dev/usr/local/share
mv $P/usr/local/share/aclocal $P-dev/usr/local/share/

# gir
#####
mkdir -p $P-gir/usr/local/lib/
mv $P/usr/local/lib/girepository-1.0 $P-gir/usr/local/lib/
mkdir -p $P-gir/usr/local/share
mv $P/usr/local/share/gir* $P-gir/usr/local/share/

# no doc
#####
rm -rf $P/usr/local/share/gtk-doc 
rm -rf $P/usr/local/share/gtk-2.0

# main
#####
mkdir -p $P/usr/local/share/$P
echo '# DO NOT EDIT! This file will be overwritten by LXAppearance.
# Any customization should be done in ~/.gtkrc-2.0.mine instead.

gtk-theme-name="Raleigh"
gtk-icon-theme-name="Adwaita"
gtk-font-name="Sans 10"
gtk-cursor-theme-name="Adwaita"
gtk-cursor-theme-size=0
gtk-toolbar-style=GTK_TOOLBAR_BOTH
gtk-toolbar-icon-size=GTK_ICON_SIZE_LARGE_TOOLBAR
gtk-button-images=1
gtk-menu-images=1
gtk-enable-event-sounds=1
gtk-enable-input-feedback-sounds=1
gtk-xft-antialias=1
gtk-xft-hinting=1
gtk-xft-hintstyle="hintfull"
gtk-xft-rgba="rgb"
include "/home/tc/.gtkrc-2.0.mine"  ' > $P/usr/local/share/$P/.gtkrc-2.0

# tce.install
#############
mkdir -p $P/usr/local/tce.installed
cat >> $P/usr/local/tce.installed/$P <<'EOF'
#!/bin/sh
gtk-query-immodules-2.0 --update-cache

USER=`cat /etc/sysconfig/tcuser`
LOOP=/tmp/tcloop/gtk2/usr/local/share/gtk2/.gtkrc-2.0
HOME=/home/$USER/.gtkrc-2.0
[ -f $HOME ] ||  cp $LOOP $HOME 
chown $USER:staff $HOME
chmod 644 $HOME
EOF
chown -R root:staff $P/usr/local/tce.installed
chmod -R 775 $P/usr/local/tce.installed

# TCZ them
#######
LIST="$P $P-dev $P-gir $P-locale"
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
        zsyncmake $Z.tcz
done

ls -hal

echo 'Title:          gtk2-dev.tcz
Description:    dev files 
Version:        2.24.32
Author:         https://github.com/GNOME/gtk/blob/master/AUTHORS
Original-site:  http://www.gtk.org
Copying-policy: LGPL v2
Size:           512K		
Extension_by:   aus9 
Tags:           gtk2
Comments:       Development files
 
Change-log:     2016/08/14 Original 2.24.30 (bmarkus)
                2017/01/29 -> 2.24.31
                2020/06/30 -> 2.24.32 (juanito)
Current:        2020/10/03 add print suppport 12x (aus9)  ' > $P-dev.tcz.info

echo 'Title:          gtk2-gir.tcz
Description:    gir files for gtk2
Version:        2.24.32
Author:         https://github.com/GNOME/gtk/blob/master/AUTHORS
Original-site:  http://www.gtk.org
Copying-policy: LGPL v2
Size:           1.8M		
Extension_by:   aus9 
Tags:           gtk2 
Comments:       introspection files for gtk2

Change-log:     2016/08/14 Original 2.24.30 (bmarkus)
                2017/01/29 -> 2.24.31
Current:        2020/06/30 -> 2.24.32 (juanito)
Current:        2020/10/03 add print suppport 12x (aus9)  ' > $P-gir.tcz.info

echo 'Title:          gtk2-locale.tcz
Description:    locales
Version:        2.24.32
Author:         https://github.com/GNOME/gtk/blob/master/AUTHORS
Original-site:  http://www.gtk.org
Copying-policy: LGPL v2
Size:           7.2M		
Extension_by:   aus9 
Tags:           gtk2 
Comments:       locales files for gtk2

Change-log:     2016/08/14 Original 2.24.30 (bmarkus)
                2017/01/29 -> 2.24.31
Current:        2020/06/30 -> 2.24.32 (juanito)
Current:        2020/10/03 add print suppport 12x (aus9)   ' > $P-locale.tcz.info

echo 'Title:          gtk2.tcz
Description:    Gimp Tool Kit
Version:        2.24.32
Author:         https://github.com/GNOME/gtk/blob/master/AUTHORS
Original-site:  http://www.gtk.org
Copying-policy: LGPL v2
Size:           1.9M		
Extension_by:   aus9 
Tags:           gtk2 
Comments:       Gimp Tool Kit
                Your config file is ~/.gtkrc-2.0 contains pathway /home/tc
                The cache update generates
                /usr/local/lib/gtk-2.0/2.10.0/immodules.cache

                Optional dependency lxappearance to modify config
                
                If you would like to input using multipress method, you need
                a keypad keyboard, numlock on and open a gtk2 app eg leafpad
                Right hand click an input area and choose input methods -> multipress
                pressing the same numlock number key quickly displays different characters
                see /usr/local/etc/gtk-2.0/im-multipress.conf
 
Change-log:     2016/08/14 Original 2.24.30 (bmarkus)
                2017/01/29 -> 2.24.31
Current:        2020/06/30 -> 2.24.32 (juanito)
Current:        2020/10/03 add print suppport 12x (aus9) ' > $P.tcz.info

echo 'gtk2.tcz 
gettext.tcz 
glib2-dev.tcz 
atk-dev.tcz 
atk-gir.tcz 
gdk-pixbuf-dev.tcz 
gdk-pixbuf-gir.tcz 
cups-dev.tcz 
gobject-introspection-dev.tcz 
pango-dev.tcz
pango-gir.tcz 
libXinerama-dev.tcz 
libXrandr-dev.tcz 
libXcursor-dev.tcz 
libXcomposite-dev.tcz ' > $P-dev.tcz.dep
echo 'atk.tcz
adwaita-icon-theme.tcz
gdk-pixbuf.tcz
libXcomposite.tcz
libXcursor.tcz
libXinerama.tcz
libXrandr.tcz
pango.tcz
shared-mime-info.tcz
Xorg.tcz ' > $P.tcz.dep

echo 'gtk2.tcz' > $P-gir.tcz.dep
echo 'gtk2.tcz' > $P-locale.tcz.dep

